==> topinfra-maven-dist-1.0.6-sources.jar: top/infra/maven/CiOptionContext.java <==
package top.infra.maven;

import java.util.Collection;
import java.util.List;
import java.util.Properties;

import top.infra.maven.extension.shared.CiOptions;
import top.infra.maven.utils.PropertiesUtils;

public class CiOptionContext {

    private final Properties systemProperties;

    private final Properties userProperties;

    public CiOptionContext(
        final Properties systemProperties,
        final Properties userProperties
    ) {
        this.systemProperties = systemProperties;
        this.userProperties = userProperties;
    }

    public Properties getSystemProperties() {
        return this.systemProperties;
    }

    public Properties getUserProperties() {
        return this.userProperties;
    }

    public Properties setCiOptPropertiesInto(
        final Collection<List<CiOption>> optionGroups,
        final Properties... targetProperties
    ) {
        final Properties properties = new Properties();

        optionGroups
            .stream()
            .flatMap(group -> group.stream().sorted())
            .forEach(ciOption -> {
                if (!ciOption.name().equals(CiOptions.name(ciOption.getPropertyName()))) {
                    throw new IllegalArgumentException(String.format(
                        "invalid property name [%s] for enum name [%s]", ciOption.name(), ciOption.getPropertyName()));
                }

                ciOption.setProperties(this, properties);
            });

        for (final Properties target : targetProperties) {
            PropertiesUtils.merge(properties, target);
        }

        return properties;
    }

    public void updateSystemProperties(final Properties externalProperties) {
        if (externalProperties != null) {
            for (final String name : externalProperties.stringPropertyNames()) {
                final String key = CiOptions.systemPropertyName(name);
                final String value = externalProperties.getProperty(name);
                if (value != null && !this.systemProperties.containsKey(key)) {
                    this.systemProperties.setProperty(key, value);
                }
            }
        }
    }
}

==> topinfra-maven-dist-1.0.8-sources.jar: top/infra/maven/CiOptionContext.java <==
package top.infra.maven;

import java.util.Collection;
import java.util.List;
import java.util.Properties;

import top.infra.maven.extension.shared.CiOptions;
import top.infra.maven.utils.PropertiesUtils;

public class CiOptionContext {

    private final Properties systemProperties;

    private final Properties userProperties;

    public CiOptionContext(
        final Properties systemProperties,
        final Properties userProperties
    ) {
        this.systemProperties = systemProperties;
        this.userProperties = userProperties;
    }

    public Properties getSystemProperties() {
        return this.systemProperties;
    }

    public Properties getUserProperties() {
        return this.userProperties;
    }

    public Properties setCiOptPropertiesInto(
        final Collection<List<CiOption>> optionGroups,
        final Properties... targetProperties
    ) {
        final Properties properties = new Properties();

        optionGroups
            .stream()
            .flatMap(group -> group.stream().sorted())
            .forEach(ciOption -> {
                if (!ciOption.name().equals(CiOptions.name(ciOption.getPropertyName()))) {
                    throw new IllegalArgumentException(String.format(
                        "invalid property name [%s] for enum name [%s]", ciOption.name(), ciOption.getPropertyName()));
                }

                ciOption.setProperties(this, properties);
            });

        for (final Properties target : targetProperties) {
            PropertiesUtils.merge(properties, target);
        }

        return properties;
    }

    public void setSystemPropertiesIfAbsent(final Properties externalProperties) {
        CiOptionContext.setSystemPropertiesIfAbsent(this.systemProperties, externalProperties);
    }

    public static void setSystemPropertiesIfAbsent(final Properties systemProperties, final Properties input) {
        if (input != null) {
            for (final String name : input.stringPropertyNames()) {
                final String key = CiOptions.systemPropertyName(name);
                final String value = input.getProperty(name);
                if (value != null && !systemProperties.containsKey(key)) {
                    systemProperties.setProperty(key, value);
                }
            }
        }
    }
}
